"""Base Asset Module

Defines the BaseAsset class, which serves as the abstract base class for all asset types.
"""

class BaseAsset:
    """BaseAsset Class

    An abstract base class for different types of assets. This class is intended to be subclassed by specific asset types.
    """
    pass
