from ._locate_workflow import LocateWorkflow
from ._draw_workflow import DrawWorkflow
from ._base_workflow import Workflow 
from ._classify_workflow import ClassifyWorkflow
from ._compare_workflow import CompareWorkflow
from ._free_text_workflow import FreeTextWorkflow
from ._select_words_workflow import SelectWordsWorkflow
from ._evaluation_workflow import EvaluationWorkflow
from ._timestamp_workflow import TimestampWorkflow
from ._ranking_workflow import RankingWorkflow
